@@ -202,67 +202,6 @@ class APIToolDescription:
         return description
 
     @classmethod
-    def generate_tool_description_text(cls, name: str, registry) -> str:
-        """
-        Генерирует текстовое описание инструмента API для документации.
-
-        Args:
-            name: Имя инструмента API
-            registry: Реестр команд
-
-        Returns:
-            Текстовое описание инструмента в формате markdown
-        """
-        tool_data = cls.generate_tool_description(name, registry)
-
-        # Формируем заголовок и базовое описание
-        text = f"# Инструмент {tool_data['name']}\n\n"
-        text += f"{tool_data['description']}\n\n"
-
-        # Список доступных команд
-        text += "## Доступные команды\n\n"
-        for cmd_name, cmd_info in tool_data["supported_commands"].items():
-            text += f"### {cmd_name}\n\n"
-            text += f"{cmd_info['description']}\n\n"
-
-            # Информация о параметрах
-            if cmd_info["params"]:
-                text += "#### Параметры:\n\n"
-                for param_name, param_info in cmd_info["params"].items():
-                    required_mark = (
-                        "**обязательный**" if param_info["required"] else "опциональный"
-                    )
-                    text += f"- `{param_name}` ({param_info['type']}, {required_mark}): {param_info['description']}\n"
-                text += "\n"
-
-            # Примеры использования
-            cmd_examples = [
-                ex for ex in tool_data["examples"] if ex["command"] == cmd_name
-            ]
-            if cmd_examples:
-                text += "#### Примеры:\n\n"
-                for i, example in enumerate(cmd_examples):
-                    text += f"**Пример {i+1}**: {example['description']}\n"
-                    text += "```json\n"
-                    text += "{\n"
-                    text += f'    "command": "{example["command"]}",\n'
-                    if example["params"]:
-                        text += '    "params": {\n'
-                        params_str = []
-                        for p_name, p_value in example["params"].items():
-                            if isinstance(p_value, str):
-                                p_str = f'        "{p_name}": "{p_value}"'
-                            else:
-                                p_str = f'        "{p_name}": {p_value}'
-                            params_str.append(p_str)
-                        text += ",\n".join(params_str)
-                        text += "\n    }\n"
-                    else:
-                        text += '    "params": {}\n'
-                    text += "}\n"
-                    text += "```\n\n"
-
-        return text
 
     @classmethod
     def _simplify_type(cls, type_str: str) -> str:
