@@ -13,6 +13,7 @@ from mcp_proxy_adapter.api.tool_integration import ToolIntegration
 from mcp_proxy_adapter.commands.command_registry import registry
 from mcp_proxy_adapter.core.errors import NotFoundError, InvalidParamsError
 
+from mcp_proxy_adapter.core.logging import get_global_logger
 logger = logging.getLogger(__name__)
 
 
@@ -48,7 +49,7 @@ class TSTCommandExecutor:
         if not params:
             params = {}
 
-        logger.info(f"Executing command via TST: {command}, params: {params}")
+        get_global_logger().info(f"Executing command via TST: {command}, params: {params}")
 
         try:
             # Проверяем существование команды
@@ -64,21 +65,13 @@ class TSTCommandExecutor:
             # Возвращаем результат
             return result.to_dict()
         except NotFoundError as e:
-            logger.error(f"Command not found: {command}")
+            get_global_logger().error(f"Command not found: {command}")
             raise
         except Exception as e:
-            logger.exception(f"Error executing command {command}: {e}")
+            get_global_logger().exception(f"Error executing command {command}: {e}")
             raise
 
     @classmethod
-    def get_schema(cls) -> Dict[str, Any]:
-        """
-        Возвращает схему инструмента в формате OpenAPI.
-
-        Returns:
-            Словарь со схемой инструмента
-        """
-        return ToolIntegration.generate_tool_schema(cls.name, registry, cls.description)
 
     @classmethod
     def get_description(cls, format: str = "json") -> Union[Dict[str, Any], str]:
@@ -166,43 +159,5 @@ class TSTCommandExecutor:
 available_tools = {TSTCommandExecutor.name: TSTCommandExecutor}
 
 
-def get_tool_description(
-    tool_name: str, format: str = "json"
-) -> Union[Dict[str, Any], str]:
-    """
-    Получает описание инструмента API по имени.
-
-    Args:
-        tool_name: Имя инструмента API
-        format: Формат описания (json, markdown, html)
-
-    Returns:
-        Описание инструмента в указанном формате
-
-    Raises:
-        NotFoundError: Если инструмент не найден
-    """
-    if tool_name in available_tools:
-        return available_tools[tool_name].get_description(format)
-    else:
-        raise NotFoundError(f"Инструмент '{tool_name}' не найден")
 
 
-async def execute_tool(tool_name: str, **params) -> Dict[str, Any]:
-    """
-    Выполняет инструмент API с указанными параметрами.
-
-    Args:
-        tool_name: Имя инструмента API
-        **params: Параметры инструмента
-
-    Returns:
-        Результат выполнения инструмента
-
-    Raises:
-        NotFoundError: Если инструмент не найден
-    """
-    if tool_name in available_tools:
-        return await available_tools[tool_name].execute(**params)
-    else:
-        raise NotFoundError(f"Инструмент '{tool_name}' не найден")
