@@ -21,6 +21,14 @@ class mTLSHandler(BaseHTTPRequestHandler):
     """Handler for mTLS connections."""
 
     def __init__(self, *args, main_app=None, **kwargs):
+        """
+        Initialize mTLS handler.
+        
+        Args:
+            *args: Positional arguments for BaseHTTPRequestHandler
+            main_app: Main FastAPI application instance
+            **kwargs: Keyword arguments for BaseHTTPRequestHandler
+        """
         self.main_app = main_app
         super().__init__(*args, **kwargs)
 
