@@ -7,8 +7,7 @@ handling configuration conversion and request validation.
 
 import json
 import logging
-from typing import Dict, Any, List, Optional
-from pathlib import Path
+from typing import Dict, Any, Optional
 
 # Import mcp_security_framework components
 try:
@@ -22,17 +21,14 @@ try:
 
     # Note: SecurityRequest and SecurityResult are not available in current version
     SECURITY_FRAMEWORK_AVAILABLE = True
-except ImportError:
-    # Fallback for when mcp_security_framework is not available
-    SECURITY_FRAMEWORK_AVAILABLE = False
-    SecurityManager = None
-    SecurityConfig = None
-    AuthConfig = None
-    SSLConfig = None
-    PermissionConfig = None
-    RateLimitConfig = None
+except ImportError as e:
+    # NO FALLBACK! mcp_security_framework is REQUIRED
+    raise RuntimeError(
+        f"CRITICAL: mcp_security_framework is required but not available: {e}. "
+        "Install it with: pip install mcp_security_framework>=1.2.8"
+    ) from e
 
-from mcp_proxy_adapter.core.logging import logger
+from mcp_proxy_adapter.core.logging import get_global_logger
 
 
 class SecurityAdapter:
@@ -55,9 +51,9 @@ class SecurityAdapter:
 
         if SECURITY_FRAMEWORK_AVAILABLE:
             self.security_manager = self._create_security_manager()
-            logger.info("Security adapter initialized with mcp_security_framework")
+            get_global_logger().info("Security adapter initialized with mcp_security_framework")
         else:
-            logger.warning("mcp_security_framework not available, using fallback mode")
+            get_global_logger().warning("mcp_security_framework not available, using fallback mode")
 
     def _create_security_manager(self) -> Optional[SecurityManager]:
         """
@@ -73,7 +69,7 @@ class SecurityAdapter:
             security_config = self._convert_config()
             return SecurityManager(security_config)
         except Exception as e:
-            logger.error(f"Failed to create SecurityManager: {e}")
+            get_global_logger().error(f"Failed to create SecurityManager: {e}")
             return None
 
     def _convert_config(self) -> SecurityConfig:
@@ -225,10 +221,10 @@ class SecurityAdapter:
         Returns:
             Validation result dictionary
         """
-        logger.debug(f"Security manager available: {self.security_manager is not None}")
+        get_global_logger().debug(f"Security manager available: {self.security_manager is not None}")
         if not self.security_manager:
             # Fallback validation when framework is not available
-            logger.debug("Using fallback validation")
+            get_global_logger().debug("Using fallback validation")
             return self._fallback_validation(request_data)
 
         try:
@@ -241,7 +237,7 @@ class SecurityAdapter:
             return result.to_dict()
 
         except Exception as e:
-            logger.error(f"Security validation failed: {e}")
+            get_global_logger().error(f"Security validation failed: {e}")
             return {
                 "is_valid": False,
                 "error_code": -32603,
@@ -286,21 +282,21 @@ class SecurityAdapter:
 
         # Check for API key in headers (FastAPI converts headers to lowercase)
         api_key = headers.get("x-api-key") or headers.get("X-API-Key")
-        logger.debug(f"API key from headers: {api_key}")
+        get_global_logger().debug(f"API key from headers: {api_key}")
 
         # Check for API key in query parameters
         if not api_key:
             api_key = query_params.get("api_key")
-            logger.debug(f"API key from query params: {api_key}")
+            get_global_logger().debug(f"API key from query params: {api_key}")
 
         # Check for API key in JSON-RPC body
         if not api_key and isinstance(body, dict):
             api_key = body.get("params", {}).get("api_key")
-            logger.debug(f"API key from body: {api_key}")
+            get_global_logger().debug(f"API key from body: {api_key}")
 
         # Get API keys from config
         api_keys = self._get_api_keys()
-        logger.debug(f"Available API keys: {list(api_keys.keys())}")
+        get_global_logger().debug(f"Available API keys: {list(api_keys.keys())}")
 
         if api_key and api_key in api_keys:
             return {
@@ -331,51 +327,17 @@ class SecurityAdapter:
         auth_config = security_config.get("auth", {})
         api_keys = auth_config.get("api_keys", {})
 
-        logger.debug(f"Security config: {security_config}")
-        logger.debug(f"Auth config: {auth_config}")
-        logger.debug(f"API keys from security config: {api_keys}")
+        get_global_logger().debug(f"Security config: {security_config}")
+        get_global_logger().debug(f"Auth config: {auth_config}")
+        get_global_logger().debug(f"API keys from security config: {api_keys}")
 
         # Fallback to legacy SSL config
         if not api_keys:
             ssl_config = self.config.get("ssl", {})
             api_keys = ssl_config.get("api_keys", {})
-            logger.debug(f"API keys from SSL config: {api_keys}")
+            get_global_logger().debug(f"API keys from SSL config: {api_keys}")
 
-        logger.info(f"Total API keys loaded: {len(api_keys)}")
+        get_global_logger().info(f"Total API keys loaded: {len(api_keys)}")
         return api_keys
 
-    def create_middleware(self, framework: str = "fastapi"):
-        """
-        Create framework-specific middleware.
 
-        Args:
-            framework: Framework type (fastapi, flask, etc.)
-
-        Returns:
-            Middleware instance
-        """
-        if not self.security_manager:
-            logger.warning("Cannot create middleware: security framework not available")
-            return None
-
-        try:
-            if framework == "fastapi":
-                from mcp_security_framework.middleware import (
-                    create_fastapi_security_middleware,
-                )
-
-                return create_fastapi_security_middleware(self.security_manager)
-            else:
-                raise ValueError(f"Unsupported framework: {framework}")
-        except Exception as e:
-            logger.error(f"Failed to create middleware: {e}")
-            return None
-
-    def is_available(self) -> bool:
-        """
-        Check if security framework is available.
-
-        Returns:
-            True if framework is available, False otherwise
-        """
-        return SECURITY_FRAMEWORK_AVAILABLE and self.security_manager is not None
