@@ -38,17 +38,14 @@ try:
     )
 
     SECURITY_FRAMEWORK_AVAILABLE = True
-except ImportError:
-    SECURITY_FRAMEWORK_AVAILABLE = False
-    SecurityManager = None
-    SecurityConfig = None
-    AuthManager = None
-    CertificateManager = None
-    PermissionManager = None
-    RateLimiter = None
-    FastAPISecurityMiddleware = None
+except ImportError as e:
+    # NO FALLBACK! mcp_security_framework is REQUIRED
+    raise RuntimeError(
+        f"CRITICAL: mcp_security_framework is required but not available: {e}. "
+        "Install it with: pip install mcp_security_framework>=1.2.8"
+    ) from e
 
-from mcp_proxy_adapter.core.logging import logger
+from mcp_proxy_adapter.core.logging import get_global_logger
 
 
 class SecurityIntegration:
@@ -81,7 +78,7 @@ class SecurityIntegration:
         self.certificate_manager = CertificateManager(self.security_config.certificates)
         self.rate_limiter = RateLimiter(self.security_config.rate_limit)
 
-        logger.info("Security integration initialized with mcp_security_framework")
+        get_global_logger().info("Security integration initialized with mcp_security_framework")
 
     def _create_security_config(self) -> SecurityConfig:
         """Create SecurityConfig from project configuration."""
@@ -126,7 +123,7 @@ class SecurityIntegration:
         if permissions_enabled:
             # If roles_file is None or empty string, don't pass it to avoid framework errors
             if roles_file is None or roles_file == "":
-                logger.warning(
+                get_global_logger().warning(
                     "roles_file is None or empty, permissions will use default configuration"
                 )
                 roles_file = None
@@ -292,7 +289,7 @@ class SecurityIntegration:
             return await self.certificate_manager.validate_certificate(cert_path)
 
         except Exception as e:
-            logger.error(f"Certificate validation failed: {e}")
+            get_global_logger().error(f"Certificate validation failed: {e}")
             return False
 
     async def extract_roles_from_certificate(self, cert_path: str) -> List[str]:
@@ -336,43 +333,10 @@ class SecurityIntegration:
         return await self.rate_limiter.get_rate_limit_info(identifier)
 
     # Middleware creation - direct use of framework middleware
-    def create_fastapi_middleware(self, app) -> FastAPISecurityMiddleware:
-        """Create FastAPI security middleware."""
-        return FastAPISecurityMiddleware(app, self.security_config)
 
     # Utility methods
-    def is_security_enabled(self) -> bool:
-        """Check if security is enabled."""
-        return self.security_config.auth.enabled or self.security_config.ssl.enabled
 
-    def get_public_paths(self) -> List[str]:
-        """Get public paths that bypass authentication."""
-        return self.security_config.auth.public_paths
 
-    def get_security_config(self) -> SecurityConfig:
-        """Get security configuration."""
-        return self.security_config
 
 
 # Factory function for easy integration
-def create_security_integration(config: Dict[str, Any]) -> SecurityIntegration:
-    """
-    Create security integration instance.
-
-    Args:
-        config: Configuration dictionary
-
-    Returns:
-        SecurityIntegration instance
-
-    Raises:
-        RuntimeError: If security integration cannot be created
-    """
-    try:
-        return SecurityIntegration(config)
-    except ImportError as e:
-        logger.error(f"mcp_security_framework not available: {e}")
-        raise RuntimeError("Security framework is required but not available") from e
-    except Exception as e:
-        logger.error(f"Failed to create security integration: {e}")
-        raise RuntimeError(f"Security integration failed: {e}") from e
