@@ -89,8 +89,17 @@ class FixedCertificateConfig(BaseModel):
 
     @field_validator("hash_algorithm")
     @classmethod
+    def validate_hash_algorithm(cls, v):
+        """Validate hash algorithm."""
+        valid_algorithms = ["sha256", "sha384", "sha512"]
+        if v not in valid_algorithms:
+            raise ValueError(f"Hash algorithm must be one of {valid_algorithms}")
+        return v
 
     @model_validator(mode="after")
+    def validate_model(self):
+        """Validate model after initialization."""
+        return self
 
 
 def create_patch_file():
