@@ -28,9 +28,15 @@ def main():
     
     # Add health endpoint
     @app.get("/health")
+    def health():
+        """Health check endpoint."""
+        return {"status": "ok"}
     
     # Add JSON-RPC endpoint
     @app.post("/api/jsonrpc")
+    def jsonrpc():
+        """JSON-RPC endpoint."""
+        return {"jsonrpc": "2.0", "result": None, "id": None}
     
     print("✅ FastAPI app created successfully")
     
