@@ -19,7 +19,7 @@ sys.path.insert(0, str(project_root))
 import aiohttp
 from aiohttp import ClientTimeout, TCPConnector
 import ssl
-from mcp_proxy_adapter.core.logging import logger
+from mcp_proxy_adapter.core.logging import get_global_logger
 
 
 class ProxyRegistrationExample:
@@ -112,15 +112,15 @@ class ProxyRegistrationExample:
                 "method": "proxy_registration",
                 "params": {"operation": "register", **server_data},
             }
-            logger.info(f"Testing registration for server: {server_data['server_id']}")
-            logger.debug(f"Request data: {json.dumps(request_data, indent=2)}")
+            get_global_logger().info(f"Testing registration for server: {server_data['server_id']}")
+            get_global_logger().debug(f"Request data: {json.dumps(request_data, indent=2)}")
             # Make request
             async with self.session.post(
                 f"{self.server_url}/cmd", json=request_data, headers=self._get_headers()
             ) as response:
                 result = await response.json()
-                logger.info(f"Response status: {response.status}")
-                logger.debug(f"Response: {json.dumps(result, indent=2)}")
+                get_global_logger().info(f"Response status: {response.status}")
+                get_global_logger().debug(f"Response: {json.dumps(result, indent=2)}")
                 return {
                     "success": response.status == 200,
                     "status_code": response.status,
@@ -128,7 +128,7 @@ class ProxyRegistrationExample:
                     "server_id": server_data["server_id"],
                 }
         except Exception as e:
-            logger.error(f"Registration test failed: {e}")
+            get_global_logger().error(f"Registration test failed: {e}")
             return {
                 "success": False,
                 "error": str(e),
@@ -149,21 +149,21 @@ class ProxyRegistrationExample:
                 "method": "proxy_registration",
                 "params": {"operation": "discover"},
             }
-            logger.info("Testing discovery operation")
+            get_global_logger().info("Testing discovery operation")
             # Make request
             async with self.session.post(
                 f"{self.server_url}/cmd", json=request_data, headers=self._get_headers()
             ) as response:
                 result = await response.json()
-                logger.info(f"Response status: {response.status}")
-                logger.debug(f"Response: {json.dumps(result, indent=2)}")
+                get_global_logger().info(f"Response status: {response.status}")
+                get_global_logger().debug(f"Response: {json.dumps(result, indent=2)}")
                 return {
                     "success": response.status == 200,
                     "status_code": response.status,
                     "result": result,
                 }
         except Exception as e:
-            logger.error(f"Discovery test failed: {e}")
+            get_global_logger().error(f"Discovery test failed: {e}")
             return {"success": False, "error": str(e)}
 
     async def test_heartbeat(self, server_key: str) -> Dict[str, Any]:
@@ -187,14 +187,14 @@ class ProxyRegistrationExample:
                     "status": "healthy",
                 },
             }
-            logger.info(f"Testing heartbeat for server: {server_key}")
+            get_global_logger().info(f"Testing heartbeat for server: {server_key}")
             # Make request
             async with self.session.post(
                 f"{self.server_url}/cmd", json=request_data, headers=self._get_headers()
             ) as response:
                 result = await response.json()
-                logger.info(f"Response status: {response.status}")
-                logger.debug(f"Response: {json.dumps(result, indent=2)}")
+                get_global_logger().info(f"Response status: {response.status}")
+                get_global_logger().debug(f"Response: {json.dumps(result, indent=2)}")
                 return {
                     "success": response.status == 200,
                     "status_code": response.status,
@@ -202,13 +202,13 @@ class ProxyRegistrationExample:
                     "server_key": server_key,
                 }
         except Exception as e:
-            logger.error(f"Heartbeat test failed: {e}")
+            get_global_logger().error(f"Heartbeat test failed: {e}")
             return {"success": False, "error": str(e), "server_key": server_key}
 
 
 async def run_proxy_registration_example():
     """Run proxy registration example."""
-    logger.info("🚀 Starting proxy registration example")
+    get_global_logger().info("🚀 Starting proxy registration example")
     # Test configurations
     test_configs = [
         {
@@ -229,9 +229,9 @@ async def run_proxy_registration_example():
     ]
     results = []
     for config in test_configs:
-        logger.info(f"\n📋 Testing: {config['name']}")
-        logger.info(f"Server URL: {config['server_url']}")
-        logger.info(f"Auth Token: {config['auth_token']}")
+        get_global_logger().info(f"\n📋 Testing: {config['name']}")
+        get_global_logger().info(f"Server URL: {config['server_url']}")
+        get_global_logger().info(f"Auth Token: {config['auth_token']}")
         async with ProxyRegistrationExample(
             config["server_url"], config["auth_token"]
         ) as client:
@@ -263,7 +263,7 @@ async def run_proxy_registration_example():
                 {"test": f"{config['name']} - Discovery", **discovery_result}
             )
     # Test without authentication
-    logger.info(f"\n📋 Testing: No Authentication")
+    get_global_logger().info(f"\n📋 Testing: No Authentication")
     async with ProxyRegistrationExample("http://localhost:8002") as client:
         for server_data in client.test_servers:
             result = await client.test_registration(server_data)
@@ -275,40 +275,40 @@ async def run_proxy_registration_example():
                 }
             )
     # Print results
-    logger.info("\n" + "=" * 80)
-    logger.info("📊 EXAMPLE RESULTS")
-    logger.info("=" * 80)
+    get_global_logger().info("\n" + "=" * 80)
+    get_global_logger().info("📊 EXAMPLE RESULTS")
+    get_global_logger().info("=" * 80)
     passed = 0
     failed = 0
     for result in results:
         status = "✅ PASS" if result["success"] else "❌ FAIL"
-        logger.info(f"{status} {result['test']}")
+        get_global_logger().info(f"{status} {result['test']}")
         if result["success"]:
             passed += 1
         else:
             failed += 1
         if "error" in result:
-            logger.error(f"   Error: {result['error']}")
+            get_global_logger().error(f"   Error: {result['error']}")
         elif "result" in result:
             result_data = result["result"]
             if "error" in result_data:
-                logger.error(f"   API Error: {result_data['error']}")
+                get_global_logger().error(f"   API Error: {result_data['error']}")
             elif "result" in result_data:
                 api_result = result_data["result"]
                 if "server_key" in api_result:
-                    logger.info(f"   Server Key: {api_result['server_key']}")
+                    get_global_logger().info(f"   Server Key: {api_result['server_key']}")
                 if "message" in api_result:
-                    logger.info(f"   Message: {api_result['message']}")
-    logger.info("\n" + "=" * 80)
-    logger.info(f"📈 SUMMARY: {passed} passed, {failed} failed")
-    logger.info("=" * 80)
+                    get_global_logger().info(f"   Message: {api_result['message']}")
+    get_global_logger().info("\n" + "=" * 80)
+    get_global_logger().info(f"📈 SUMMARY: {passed} passed, {failed} failed")
+    get_global_logger().info("=" * 80)
     return passed, failed
 
 
 def main():
     """Main function for the example."""
-    logger.info("🔧 MCP Proxy Adapter - Proxy Registration Example")
-    logger.info("=" * 60)
+    get_global_logger().info("🔧 MCP Proxy Adapter - Proxy Registration Example")
+    get_global_logger().info("=" * 60)
     # Check if server is running
     import socket
 
@@ -316,15 +316,15 @@ def main():
     result = sock.connect_ex(("localhost", 8002))
     sock.close()
     if result != 0:
-        logger.error("❌ Server is not running on localhost:8002")
-        logger.info("💡 Please start the server first:")
-        logger.info("   cd mcp_proxy_adapter/examples")
-        logger.info(
+        get_global_logger().error("❌ Server is not running on localhost:8002")
+        get_global_logger().info("💡 Please start the server first:")
+        get_global_logger().info("   cd mcp_proxy_adapter/examples")
+        get_global_logger().info(
             "   python -m mcp_proxy_adapter.main --config server_configs/config_proxy_registration.json"
         )
         sys.exit(1)
-    logger.info("✅ Server is running on localhost:8002")
-    logger.info("🚀 Starting proxy registration example...")
+    get_global_logger().info("✅ Server is running on localhost:8002")
+    get_global_logger().info("🚀 Starting proxy registration example...")
     # Run example
     passed, failed = asyncio.run(run_proxy_registration_example())
     # Exit with appropriate code
