@@ -444,35 +444,6 @@ class FullTestSuiteRunner:
         # Process cleanup is handled by the test scripts themselves
         print("✅ Cleanup completed")
 
-    def cleanup_directories(self) -> bool:
-        """Clean up existing test directories before starting."""
-        self.print_info("Cleaning up existing test directories...")
-
-        try:
-            import shutil
-
-            # Directories to clean
-            dirs_to_clean = [self.configs_dir, self.certs_dir, self.keys_dir]
-            files_to_clean = [self.working_dir / "roles.json"]
-
-            # Remove directories
-            for dir_path in dirs_to_clean:
-                if dir_path.exists():
-                    shutil.rmtree(dir_path)
-                    print(f"🗑️  Removed directory: {dir_path}")
-
-            # Remove files
-            for file_path in files_to_clean:
-                if file_path.exists():
-                    file_path.unlink()
-                    print(f"🗑️  Removed file: {file_path}")
-
-            self.print_success("Directory cleanup completed")
-            return True
-
-        except Exception as e:
-            self.print_error(f"Failed to cleanup directories: {e}")
-            return False
 
     def test_all_configurations(self) -> bool:
         """Test all server configurations including proxy registration."""
