@@ -26,6 +26,7 @@ from pathlib import Path
 
 # Import mcp_security_framework
 try:
+    from mcp_security_framework.schemas.config import (
         CertificateConfig,
         CAConfig,
         ServerCertConfig,
@@ -38,15 +39,19 @@ except ImportError:
     print("Warning: mcp_security_framework not available")
 
 # Import setup modules
-    ConfigurationValidator,
-    create_test_files,
-    create_configuration_documentation,
-    generate_enhanced_configurations,
-    generate_certificates_with_framework,
-    test_proxy_registration,
-    run_full_test_suite,
-    setup_test_environment,
-)
+try:
+    from mcp_proxy_adapter.examples.setup import (
+        ConfigurationValidator,
+        create_test_files,
+        create_configuration_documentation,
+        generate_enhanced_configurations,
+        generate_certificates_with_framework,
+        test_proxy_registration,
+        run_full_test_suite,
+        setup_test_environment,
+    )
+except ImportError:
+    print("Warning: Setup modules not available")
 
 
 def _get_package_paths() -> tuple[Path, Path]:
