@@ -11,9 +11,7 @@ import os
 import sys
 import argparse
 import time
-import subprocess
 from pathlib import Path
-from typing import Dict, Any, Optional
 
 # Import mcp_security_framework
 try:
@@ -28,9 +26,49 @@ except ImportError:
 sys.path.insert(0, os.path.join(os.path.dirname(__file__), "../.."))
 
 
+def validate_config_with_new_system(config: Dict[str, Any]) -> bool:
+    """
+    Validate configuration using the new validation system.
+    Args:
+        config: Configuration dictionary
+    Returns:
+        True if validation passed, False otherwise
+    """
+    try:
+        from mcp_proxy_adapter.core.config_validator import ConfigValidator
+        
+        print("🔍 Validating configuration with new validation system...")
+        validator = ConfigValidator()
+        validator.config_data = config
+        results = validator.validate_config()
+        
+        if results:
+            print("⚠️ Validation issues found:")
+            for result in results:
+                level_symbol = {
+                    "error": "❌",
+                    "warning": "⚠️",
+                    "info": "ℹ️"
+                }[result.level]
+                print(f"  {level_symbol} {result.message}")
+                if result.suggestion:
+                    print(f"     Suggestion: {result.suggestion}")
+            return False
+        else:
+            print("✅ Configuration validation passed!")
+            return True
+            
+    except ImportError:
+        print("⚠️ New validation system not available")
+        return True
+    except Exception as e:
+        print(f"❌ Validation error: {e}")
+        return False
+
+
 def validate_security_config(config: Dict[str, Any]) -> bool:
     """
-    Validate security configuration using mcp_security_framework.
+    Validate security configuration using mcp_security_framework (legacy).
     Args:
         config: Configuration dictionary
     Returns:
@@ -102,7 +140,11 @@ def test_configuration(config_path: str, timeout: int = 30) -> bool:
                 print(f"  - {error}")
             return False
         print("✅ Configuration validation passed")
-        # Validate security configuration
+        # Validate configuration with new system
+        if not validate_config_with_new_system(config):
+            return False
+        
+        # Validate security configuration (legacy)
         if not validate_security_config(config):
             return False
         # Test server startup (without actually starting)
