@@ -14,6 +14,9 @@ from .queuemgr_integration import (
     QueueJobResult,
     QueueJobStatus,
     QueueJobError,
+    init_global_queue_manager,
+    shutdown_global_queue_manager,
+    get_global_queue_manager,
 )
 
 __all__ = [
@@ -22,4 +25,7 @@ __all__ = [
     "QueueJobResult",
     "QueueJobStatus",
     "QueueJobError",
+    "init_global_queue_manager",
+    "shutdown_global_queue_manager",
+    "get_global_queue_manager",
 ]
