@@ -331,28 +331,6 @@ class OpenApiGenerator:
             if path not in schema["paths"]:
                 raise SchemaValidationError(f"Missing required path: {path}")
 
-    def generate(self) -> Dict[str, Any]:
-        """
-        Generate complete OpenAPI schema
-
-        Returns:
-            OpenAPI schema as dictionary
-        """
-        schema = self._base_schema.copy()
-
-        # Add commands to schema
-        self._add_commands_to_schema(schema)
-
-        # Add /cmd endpoint regardless of commands
-        self._add_cmd_endpoint(schema)
-        self._add_cmd_models(schema)
-        self._add_cmd_examples(schema)
-
-        # Validate required paths
-        self._validate_required_paths(schema)
-
-        self.validate_schema(schema)
-        return schema
 
     def validate_schema(self, schema: Dict[str, Any]):
         """
