@@ -18,7 +18,8 @@ import sys
 sys.path.insert(0, str(Path(__file__).parent.parent))
 
 # Import only the validation modules directly
-from mcp_proxy_adapter.core.config_validator import ConfigValidator, ValidationLevel, ValidationResult
+from mcp_proxy_adapter.core.config_validator import ConfigValidator
+from mcp_proxy_adapter.core.validation.validation_result import ValidationResult, ValidationLevel
 
 
 class TestConfigValidationIsolated(unittest.TestCase):
