@@ -8,6 +8,10 @@ import asyncio
 import json
 sys.path.insert(0, os.path.join(os.path.dirname(__file__), 'mcp_proxy_adapter'))
 
+# Skip this file in pytest runs - it's a standalone script
+import pytest
+pytest.skip("Standalone scenario", allow_module_level=True)
+
 from mcp_proxy_adapter.commands.command_registry import registry
 from mcp_proxy_adapter.config import Config
 
